@@ -25,31 +25,14 @@ Python integers. This module is some kind of a hack and its use
 outside of *Snimpy* seems convoluted.
 """
 
-import sys
 import struct
-import socket
 import re
+import ipaddress
 from datetime import timedelta
 from pysnmp.proto import rfc1902
 
 from snimpy import mib
 
-PYTHON3 = sys.version_info >= (3, 0)
-if PYTHON3:
-    def ord2(x):
-        return x
-
-    def chr2(x):
-        return bytes([x & 0xff])
-
-    unicode = str
-    long = int
-else:
-    ord2 = ord
-
-    def chr2(x):
-        return chr(x & 0xff)
-
 
 def ordering_with_cmp(cls):
     ops = {'__lt__': lambda self, other: self.__cmp__(other) < 0,
@@ -65,7 +48,7 @@ def ordering_with_cmp(cls):
     return cls
 
 
-class Type(object):
+class Type:
 
     """Base class for all types."""
 
@@ -82,24 +65,24 @@ class Type(object):
         :return: an instance of the new typed value
         """
         if entity.type != cls:
-            raise ValueError("MIB node is {0}. We are {1}".format(entity.type,
-                                                                  cls))
+            raise ValueError("MIB node is {}. We are {}".format(entity.type,
+                                                                cls))
 
         if cls == OctetString and entity.fmt is not None:
             # Promotion of OctetString to String if we have unicode stuff
-            if isinstance(value, (String, unicode)) or not raw:
+            if isinstance(value, (String, str)) or not raw:
                 cls = String
 
         if not isinstance(value, Type):
             value = cls._internal(entity, value)
         else:
             value = cls._internal(entity, value._value)
-        if issubclass(cls, unicode):
-            self = unicode.__new__(cls, value)
+        if issubclass(cls, str):
+            self = str.__new__(cls, value)
         elif issubclass(cls, bytes):
             self = bytes.__new__(cls, value)
-        elif issubclass(cls, long):
-            self = long.__new__(cls, value)
+        elif issubclass(cls, int):
+            self = int.__new__(cls, value)
         else:
             self = object.__new__(cls)
 
@@ -113,7 +96,7 @@ class Type(object):
             # individual bytes in this format, only the full displayed
             # version.
             value = String._internal(entity, self)
-            self = unicode.__new__(String, value)
+            self = str.__new__(String, value)
             self._value = value
             self.entity = entity
 
@@ -125,6 +108,10 @@ class Type(object):
 
         return self
 
+    def __init__(self, *args, **kwargs):
+        # Neutralize __init__ from other inherited classes
+        pass
+
     @classmethod
     def _internal(cls, entity, value):
         """Get internal value for a given value."""
@@ -188,12 +175,12 @@ class Type(object):
         return str(self._value)
 
     def __repr__(self):
-        return '<{0}: {1}>'.format(self.__class__.__name__,
-                                   str(self))
+        return '<{}: {}>'.format(self.__class__.__name__,
+                                 str(self))
 
 
 @ordering_with_cmp
-class IpAddress(Type):
+class IpAddress(Type, ipaddress.IPv4Address):
 
     """Class representing an IP address/"""
 
@@ -201,33 +188,25 @@ class IpAddress(Type):
     def _internal(cls, entity, value):
         if isinstance(value, (list, tuple)):
             value = ".".join([str(a) for a in value])
-        elif isinstance(value, bytes) and len(value) == 4:
-            value = socket.inet_ntoa(value)
         try:
-            value = socket.inet_ntoa(socket.inet_aton(value))
-        except socket.error:
-            raise ValueError("{0!r} is not a valid IP".format(value))
-        return [int(a) for a in value.split(".")]
+            value = ipaddress.IPv4Address(value)
+        except ipaddress.AddressValueError:
+            raise ValueError("{!r} is not a valid IP".format(value))
+        return value
 
     def pack(self):
-        return (
-            rfc1902.IpAddress(
-                str(".".join(["{0:d}".format(x) for x in self._value])))
-        )
+        return rfc1902.IpAddress(str(self._value))
 
     def toOid(self, implied=False):
-        return tuple(self._value)
+        return tuple(self._value.packed)
 
     @classmethod
     def fromOid(cls, entity, oid, implied=False):
         if len(oid) < 4:
             raise ValueError(
-                "{0!r} is too short for an IP address".format(oid))
+                "{!r} is too short for an IP address".format(oid))
         return (4, cls(entity, oid[:4]))
 
-    def __str__(self):
-        return ".".join([str(a) for a in self._value])
-
     def __cmp__(self, other):
         if not isinstance(other, IpAddress):
             try:
@@ -241,7 +220,7 @@ class IpAddress(Type):
         return 1
 
     def __getitem__(self, nb):
-        return self._value[nb]
+        return self._value.packed[nb]
 
 
 class StringOrOctetString(Type):
@@ -253,26 +232,27 @@ class StringOrOctetString(Type):
         b = self._toBytes()
 
         if implied or self._fixedLen(self.entity):
-            return tuple(ord2(a) for a in b)
+            return tuple(b)
         else:
-            return tuple([len(b)] + [ord2(a) for a in b])
+            return (len(b),) + tuple(b)
 
     def _toBytes(self):
         raise NotImplementedError
 
     @classmethod
     def fromOid(cls, entity, oid, implied=False):
+        oid = tuple(o & 0xff for o in oid)
         if implied:
             # Eat everything
-            return (len(oid), cls(entity, b"".join([chr2(x) for x in oid])))
+            return (len(oid), cls(entity, bytes(oid)))
         if cls._fixedLen(entity):
             length = entity.ranges
             if len(oid) < length:
                 raise ValueError(
-                    "{0} is too short for wanted fixed "
-                    "string (need at least {1:d})".format(oid, length))
+                    "{} is too short for wanted fixed "
+                    "string (need at least {:d})".format(oid, length))
             return (length,
-                    cls(entity, b"".join([chr2(x) for x in oid[:length]])))
+                    cls(entity, bytes(oid[:length])))
 
         # This is var-len
         if not oid:
@@ -280,11 +260,11 @@ class StringOrOctetString(Type):
         length = oid[0]
         if len(oid) < length + 1:
             raise ValueError(
-                "{0} is too short for variable-len "
-                "string (need at least {1:d})".format(oid, length))
+                "{} is too short for variable-len "
+                "string (need at least {:d})".format(oid, length))
         return (
             (length + 1,
-             cls(entity, b"".join([chr2(x) for x in oid[1:(length + 1)]]))))
+             cls(entity, bytes(oid[1:(length + 1)]))))
 
     def pack(self):
         return rfc1902.OctetString(self._toBytes())
@@ -303,7 +283,7 @@ class OctetString(StringOrOctetString, bytes):
         # Internally, we are using bytes
         if isinstance(value, bytes):
             return value
-        if isinstance(value, unicode):
+        if isinstance(value, str):
             return value.encode("ascii")
         return bytes(value)
 
@@ -311,38 +291,38 @@ class OctetString(StringOrOctetString, bytes):
         return self._value
 
     def __ior__(self, value):
-        nvalue = [ord2(u) for u in self._value]
+        nvalue = bytearray(self._value)
         if not isinstance(value, (tuple, list)):
             value = [value]
         for v in value:
-            if not isinstance(v, (int, long)):
+            if not isinstance(v, int):
                 raise NotImplementedError(
                     "on string, bit-operation are limited to integers")
             if len(nvalue) < (v >> 3) + 1:
                 nvalue.extend([0] * ((v >> 3) + 1 - len(self._value)))
             nvalue[v >> 3] |= 1 << (7 - v % 8)
-        return self.__class__(self.entity, b"".join([chr2(i) for i in nvalue]))
+        return self.__class__(self.entity, bytes(nvalue))
 
     def __isub__(self, value):
-        nvalue = [ord2(u) for u in self._value]
+        nvalue = bytearray(self._value)
         if not isinstance(value, (tuple, list)):
             value = [value]
         for v in value:
-            if not isinstance(v, int) and not isinstance(v, long):
+            if not isinstance(v, int):
                 raise NotImplementedError(
                     "on string, bit-operation are limited to integers")
             if len(nvalue) < (v >> 3) + 1:
                 continue
             nvalue[v >> 3] &= ~(1 << (7 - v % 8))
-        return self.__class__(self.entity, b"".join([chr2(i) for i in nvalue]))
+        return self.__class__(self.entity, bytes(nvalue))
         return self
 
     def __and__(self, value):
-        nvalue = [ord2(u) for u in self._value]
+        nvalue = bytearray(self._value)
         if not isinstance(value, (tuple, list)):
             value = [value]
         for v in value:
-            if not isinstance(v, (int, long)):
+            if not isinstance(v, int):
                 raise NotImplementedError(
                     "on string, bit-operation are limited to integers")
             if len(nvalue) < (v >> 3) + 1:
@@ -352,7 +332,7 @@ class OctetString(StringOrOctetString, bytes):
         return True
 
 
-class String(StringOrOctetString, unicode):
+class String(StringOrOctetString, str):
 
     """Class for a display string. Such a string is an unicode string and
     it is therefore expected that only printable characters are
@@ -416,7 +396,7 @@ class String(StringOrOctetString, unicode):
 
             # building
             if dorepeat:
-                repeat = ord2(value[i])
+                repeat = value[i]
                 i += 1
             else:
                 repeat = 1
@@ -443,8 +423,8 @@ class String(StringOrOctetString, unicode):
                 elif format == "t":
                     result += bb.decode("utf-8")
                 else:
-                    raise ValueError("{0!r} cannot be represented with "
-                                     "the given display string ({1})".format(
+                    raise ValueError("{!r} cannot be represented with "
+                                     "the given display string ({})".format(
                                          bb, fmt))
                 result += sep
             if sep and term:
@@ -480,16 +460,16 @@ class String(StringOrOctetString, unicode):
                 elif format == "t":
                     fmatch = "(?P<t>(?:.|\n){{1,{0}}})".format(length)
                 else:
-                    raise ValueError("{0!r} cannot be parsed due to an "
-                                     "incorrect format ({1})".format(
+                    raise ValueError("{!r} cannot be parsed due to an "
+                                     "incorrect format ({})".format(
                                          self._value, fmt))
             repeats = []
             while True:
                 mo = re.match(fmatch, self._value[i:])
                 if not mo:
-                    raise ValueError("{0!r} cannot be parsed because it "
-                                     "does not match format {1} at "
-                                     "index {2}".format(self._value, fmt, i))
+                    raise ValueError("{!r} cannot be parsed because it "
+                                     "does not match format {} at "
+                                     "index {}".format(self._value, fmt, i))
                 if format in ["o", "x", "d"]:
                     if format == "o":
                         r = int(mo.group("o"), 8)
@@ -515,7 +495,7 @@ class String(StringOrOctetString, unicode):
                 else:
                     break
             if dorepeat:
-                bb += chr2(len(repeats))
+                bb += bytes([len(repeats)])
                 bb += b"".join(repeats)
             else:
                 bb += result
@@ -531,21 +511,21 @@ class String(StringOrOctetString, unicode):
         # case if the value is an OctetString to do the conversion.
         if isinstance(value, OctetString):
             return cls._fromBytes(value._value, entity.fmt)
-        if PYTHON3 and isinstance(value, bytes):
+        if isinstance(value, bytes):
             return value.decode("utf-8")
-        return unicode(value)
+        return str(value)
 
     def __str__(self):
         return self._value
 
 
-class Integer(Type, long):
+class Integer(Type, int):
 
     """Class for any integer."""
 
     @classmethod
     def _internal(cls, entity, value):
-        return long(value)
+        return int(value)
 
     def pack(self):
         if self._value >= (1 << 64):
@@ -564,7 +544,7 @@ class Integer(Type, long):
     @classmethod
     def fromOid(cls, entity, oid, implied=False):
         if len(oid) < 1:
-            raise ValueError("{0} is too short for an integer".format(oid))
+            raise ValueError("{} is too short for an integer".format(oid))
         return (1, cls(entity, oid[0]))
 
     def __str__(self):
@@ -590,7 +570,7 @@ class Integer(Type, long):
                 result = str(self._value)
                 if len(result) < dec + 1:
                     result = "0" * (dec + 1 - len(result)) + result
-                return "{0}.{1}".format(result[:-2], result[-2:])
+                return "{}.{}".format(result[:-2], result[-2:])
         return str(self._value)
 
 
@@ -631,11 +611,11 @@ class Enum(Integer):
             if (v == value):
                 return k
         try:
-            return long(value)
+            return int(value)
         except Exception:
-            raise ValueError("{0!r} is not a valid "
-                             "value for {1}".format(value,
-                                                    entity))
+            raise ValueError("{!r} is not a valid "
+                             "value for {}".format(value,
+                                                   entity))
 
     def pack(self):
         return rfc1902.Integer(self._value)
@@ -644,7 +624,7 @@ class Enum(Integer):
     def fromOid(cls, entity, oid, implied=False):
         if len(oid) < 1:
             raise ValueError(
-                "{0!r} is too short for an enumeration".format(oid))
+                "{!r} is too short for an enumeration".format(oid))
         return (1, cls(entity, oid[0]))
 
     def __eq__(self, other):
@@ -661,7 +641,7 @@ class Enum(Integer):
     def __str__(self):
         if self._value in self.entity.enum:
             return (
-                "{0}({1:d})".format(self.entity.enum[self._value], self._value)
+                "{}({:d})".format(self.entity.enum[self._value], self._value)
             )
         else:
             return str(self._value)
@@ -675,14 +655,14 @@ class Oid(Type):
     @classmethod
     def _internal(cls, entity, value):
         if isinstance(value, (list, tuple)):
-            return tuple([int(v) for v in value])
+            return tuple(int(v) for v in value)
         elif isinstance(value, str):
-            return tuple([ord2(i) for i in value.split(".") if i])
+            return tuple(int(i) for i in value.split(".") if i)
         elif isinstance(value, mib.Node):
             return tuple(value.oid)
         else:
             raise TypeError(
-                "don't know how to convert {0!r} to OID".format(value))
+                "don't know how to convert {!r} to OID".format(value))
 
     def pack(self):
         return rfc1902.univ.ObjectIdentifier(self._value)
@@ -698,18 +678,18 @@ class Oid(Type):
         if cls._fixedLen(entity):
             # A fixed OID? We don't like this. Provide a real example.
             raise ValueError(
-                "{0!r} seems to be a fixed-len OID index. Odd.".format(entity))
+                "{!r} seems to be a fixed-len OID index. Odd.".format(entity))
         if not implied:
             # This index is not implied. We need the len
             if len(oid) < 1:
                 raise ValueError(
-                    "{0!r} is too short for a not "
+                    "{!r} is too short for a not "
                     "implied index".format(entity))
             length = oid[0]
             if len(oid) < length + 1:
                 raise ValueError(
-                    "{0!r} has an incorrect size "
-                    "(needs at least {1:d})".format(oid, length))
+                    "{!r} has an incorrect size "
+                    "(needs at least {:d})".format(oid, length))
             return (length + 1, cls(entity, oid[1:(length + 1)]))
         else:
             # This index is implied. Eat everything
@@ -769,14 +749,14 @@ class Timeticks(Type):
 
     @classmethod
     def _internal(cls, entity, value):
-        if isinstance(value, (int, long)):
+        if isinstance(value, int):
             # Value in centiseconds
             return timedelta(0, value / 100.)
         elif isinstance(value, timedelta):
             return value
         else:
             raise TypeError(
-                "dunno how to handle {0!r} ({1})".format(value, type(value)))
+                "dunno how to handle {!r} ({})".format(value, type(value)))
 
     def __int__(self):
         return self._value.days * 3600 * 24 * 100 + \
@@ -789,7 +769,7 @@ class Timeticks(Type):
     @classmethod
     def fromOid(cls, entity, oid, implied=False):
         if len(oid) < 1:
-            raise ValueError("{0!r} is too short for a timetick".format(oid))
+            raise ValueError("{!r} is too short for a timetick".format(oid))
         return (1, cls(entity, oid[0]))
 
     def pack(self):
@@ -801,12 +781,12 @@ class Timeticks(Type):
     def __cmp__(self, other):
         if isinstance(other, Timeticks):
             other = other._value
-        elif isinstance(other, (int, long)):
+        elif isinstance(other, int):
             other = timedelta(0, other / 100.)
         elif not isinstance(other, timedelta):
             raise NotImplementedError(
                 "only compare to int or "
-                "timedelta, not {0}".format(type(other)))
+                "timedelta, not {}".format(type(other)))
         if self._value == other:
             return 0
         if self._value < other:
@@ -824,10 +804,10 @@ class Bits(Type):
         tryalternate = False
         if isinstance(value, bytes):
             for i, x in enumerate(value):
-                if ord2(x) == 0:
+                if x == 0:
                     continue
                 for j in range(8):
-                    if ord2(x) & (1 << (7 - j)):
+                    if x & (1 << (7 - j)):
                         k = (i * 8) + j
                         if k not in entity.enum:
                             tryalternate = True
@@ -840,7 +820,7 @@ class Bits(Type):
             else:
                 bits = set()
         elif not isinstance(value, (tuple, list, set, frozenset)):
-            value = set([value])
+            value = {value}
         for v in value:
             found = False
             if v in entity.enum:
@@ -853,7 +833,7 @@ class Bits(Type):
                         found = True
                         break
             if not found:
-                raise ValueError("{0!r} is not a valid bit value".format(v))
+                raise ValueError("{!r} is not a valid bit value".format(v))
         return bits
 
     def pack(self):
@@ -863,7 +843,7 @@ class Bits(Type):
             string = []
         for b in self._value:
             string[b // 8] |= 1 << (7 - b % 8)
-        return rfc1902.Bits(b"".join([chr2(x) for x in string]))
+        return rfc1902.Bits(bytes(string))
 
     def __eq__(self, other):
         if isinstance(other, str):
@@ -878,7 +858,7 @@ class Bits(Type):
     def __str__(self):
         result = []
         for b in sorted(self._value):
-            result.append("{0}({1:d})".format(self.entity.enum[b], b))
+            result.append("{}({:d})".format(self.entity.enum[b], b))
         return ", ".join(result)
 
     def __and__(self, other):
