@@ -1,4 +1,3 @@
-import sys
 import os
 import tempfile
 import code  # noqa: F401
@@ -7,10 +6,7 @@ import platform
 from snimpy.main import interact
 from multiprocessing import Process
 import agent
-if sys.version_info < (2, 7):
-    import unittest2 as unittest
-else:
-    import unittest
+import unittest
 
 
 class TestMain(unittest.TestCase):
@@ -32,7 +28,7 @@ class TestMain(unittest.TestCase):
         try:
             script.write("""
 load("IF-MIB")
-m = M(host="127.0.0.1:{0}",
+m = M(host="127.0.0.1:{}",
       community="public",
       version=2)
 assert(m.ifDescr[1] == "lo")
