@@ -1,12 +1,7 @@
 import unittest
 import os
-import sys
 from snimpy import mib, basictypes
 
-PYTHON3 = sys.version_info >= (3, 0)
-if PYTHON3:
-    unicode = str
-
 
 class TestMibSnimpy(unittest.TestCase):
 
@@ -69,11 +64,11 @@ class TestMibSnimpy(unittest.TestCase):
         self.notifications = ["snimpyNotification"]
         self.notifications.sort()
 
-        self.expected_modules = [u"SNMPv2-SMI",
-                                 u"SNMPv2-TC",
-                                 u"SNIMPY-MIB",
-                                 u"INET-ADDRESS-MIB",
-                                 u"IANAifType-MIB"]
+        self.expected_modules = ["SNMPv2-SMI",
+                                 "SNMPv2-TC",
+                                 "SNIMPY-MIB",
+                                 "INET-ADDRESS-MIB",
+                                 "IANAifType-MIB"]
 
     def tearDown(self):
         mib.reset()
@@ -85,7 +80,7 @@ class TestMibSnimpy(unittest.TestCase):
         self.assertEqual(self.nodes,
                          snodes)
         for n in nodes:
-            self.assert_(isinstance(n, mib.Node))
+            self.assertTrue(isinstance(n, mib.Node))
 
     def testGetTables(self):
         """Test that we can get all tables"""
@@ -94,7 +89,7 @@ class TestMibSnimpy(unittest.TestCase):
         self.assertEqual(self.tables,
                          stables)
         for n in tables:
-            self.assert_(isinstance(n, mib.Table))
+            self.assertTrue(isinstance(n, mib.Table))
 
     def testGetColumns(self):
         """Test that we can get all columns"""
@@ -103,7 +98,7 @@ class TestMibSnimpy(unittest.TestCase):
         self.assertEqual(self.columns,
                          scolumns)
         for n in columns:
-            self.assert_(isinstance(n, mib.Column))
+            self.assertTrue(isinstance(n, mib.Column))
 
     def testGetScalars(self):
         """Test that we can get all scalars"""
@@ -111,7 +106,7 @@ class TestMibSnimpy(unittest.TestCase):
         sscalars = sorted([str(a) for a in scalars])
         self.assertEqual(self.scalars, sscalars)
         for n in scalars:
-            self.assert_(isinstance(n, mib.Scalar))
+            self.assertTrue(isinstance(n, mib.Scalar))
 
     def testGetNotifications(self):
         """Test that we can get all notifications"""
@@ -119,50 +114,53 @@ class TestMibSnimpy(unittest.TestCase):
         snotifications = sorted([str(a) for a in notifications])
         self.assertEqual(self.notifications, snotifications)
         for n in notifications:
-            self.assert_(isinstance(n, mib.Notification))
+            self.assertTrue(isinstance(n, mib.Notification))
 
     def testGet(self):
         """Test that we can get all named attributes"""
         for i in self.scalars:
             self.assertEqual(str(mib.get('SNIMPY-MIB', i)), i)
-            self.assert_(isinstance(mib.get('SNIMPY-MIB', i), mib.Scalar))
+            self.assertTrue(isinstance(mib.get('SNIMPY-MIB', i), mib.Scalar))
         for i in self.tables:
             self.assertEqual(str(mib.get('SNIMPY-MIB', i)), i)
-            self.assert_(isinstance(mib.get('SNIMPY-MIB', i), mib.Table))
+            self.assertTrue(isinstance(mib.get('SNIMPY-MIB', i), mib.Table))
         for i in self.columns:
             self.assertEqual(str(mib.get('SNIMPY-MIB', i)), i)
-            self.assert_(isinstance(mib.get('SNIMPY-MIB', i), mib.Column))
+            self.assertTrue(isinstance(mib.get('SNIMPY-MIB', i), mib.Column))
         for i in self.nodes:
             self.assertEqual(str(mib.get('SNIMPY-MIB', i)), i)
-            self.assert_(isinstance(mib.get('SNIMPY-MIB', i), mib.Node))
+            self.assertTrue(isinstance(mib.get('SNIMPY-MIB', i), mib.Node))
         for i in self.notifications:
             self.assertEqual(str(mib.get('SNIMPY-MIB', i)), i)
-            self.assert_(isinstance(mib.get('SNIMPY-MIB', i),
-                         mib.Notification))
+            self.assertTrue(isinstance(mib.get('SNIMPY-MIB', i),
+                                       mib.Notification))
 
     def testGetByOid(self):
         """Test that we can get all named attributes by OID."""
         for i in self.scalars:
             nodebyname = mib.get('SNIMPY-MIB', i)
             self.assertEqual(str(mib.getByOid(nodebyname.oid)), i)
-            self.assert_(isinstance(mib.getByOid(nodebyname.oid), mib.Scalar))
+            self.assertTrue(isinstance(mib.getByOid(nodebyname.oid),
+                                       mib.Scalar))
         for i in self.tables:
             nodebyname = mib.get('SNIMPY-MIB', i)
             self.assertEqual(str(mib.getByOid(nodebyname.oid)), i)
-            self.assert_(isinstance(mib.getByOid(nodebyname.oid), mib.Table))
+            self.assertTrue(isinstance(mib.getByOid(nodebyname.oid),
+                                       mib.Table))
         for i in self.columns:
             nodebyname = mib.get('SNIMPY-MIB', i)
             self.assertEqual(str(mib.getByOid(nodebyname.oid)), i)
-            self.assert_(isinstance(mib.getByOid(nodebyname.oid), mib.Column))
+            self.assertTrue(isinstance(mib.getByOid(nodebyname.oid),
+                                       mib.Column))
         for i in self.nodes:
             nodebyname = mib.get('SNIMPY-MIB', i)
             self.assertEqual(str(mib.getByOid(nodebyname.oid)), i)
-            self.assert_(isinstance(mib.getByOid(nodebyname.oid), mib.Node))
+            self.assertTrue(isinstance(mib.getByOid(nodebyname.oid), mib.Node))
         for i in self.notifications:
             nodebyname = mib.get('SNIMPY-MIB', i)
             self.assertEqual(str(mib.getByOid(nodebyname.oid)), i)
-            self.assert_(isinstance(mib.getByOid(nodebyname.oid),
-                                    mib.Notification))
+            self.assertTrue(isinstance(mib.getByOid(nodebyname.oid),
+                                       mib.Notification))
 
     def testGetByOid_UnknownOid(self):
         """Test that unknown OIDs raise an exception."""
@@ -182,9 +180,9 @@ class TestMibSnimpy(unittest.TestCase):
         for i in self.tables:
             table = mib.get('SNIMPY-MIB', i)
             for r in table.columns:
-                self.assert_(isinstance(r, mib.Column))
+                self.assertTrue(isinstance(r, mib.Column))
                 self.assertEqual(str(r.table), str(i))
-                self.assert_(str(r).startswith(str(i).replace("Table", "")))
+                self.assertTrue(str(r).startswith(str(i).replace("Table", "")))
             columns = sorted([str(rr)
                               for rr in self.columns
                               if str(rr).startswith(str(i).replace("Table",
@@ -195,7 +193,7 @@ class TestMibSnimpy(unittest.TestCase):
         for r in self.columns:
             column = mib.get('SNIMPY-MIB', r)
             table = column.table
-            self.assert_(isinstance(table, mib.Table))
+            self.assertTrue(isinstance(table, mib.Table))
             prefix = str(table).replace("Table", "")
             self.assertEqual(prefix, str(r)[:len(prefix)])
 
@@ -347,7 +345,7 @@ class TestMibSnimpy(unittest.TestCase):
         addrtype = addrtype_attr.type(addrtype_attr, "ipv4")
         self.assertEqual(addrtype, "ipv4")
         addr_attr.typeName = b"InetAddressIPv4"
-        ipv4 = u"127.0.0.1"
+        ipv4 = "127.0.0.1"
         ipv4_oid = (4, 127, 0, 0, 1)
 
         addr = addr_attr.type(addr_attr, ipv4)
@@ -362,9 +360,9 @@ class TestMibSnimpy(unittest.TestCase):
         # Try both IPv6 and non-bytes name.
         addrtype = addrtype_attr.type(addrtype_attr, "ipv6")
         self.assertEqual(addrtype, "ipv6")
-        addr_attr.typeName = u"InetAddressIPv6"
+        addr_attr.typeName = "InetAddressIPv6"
         # Snimpy does not use leading zeroes.
-        ipv6 = u'102:304:506:708:90a:b0c:d0e:f01'
+        ipv6 = '102:304:506:708:90a:b0c:d0e:f01'
         ipv6_oid = (16, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08,
                     0x09, 0x0a, 0x0b, 0x0c, 0x0d, 0x0e, 0x0f, 0x01)
 
@@ -379,7 +377,7 @@ class TestMibSnimpy(unittest.TestCase):
 
         # Try a type from a different module (chosen because snmpwalk
         # prints IPv6 addresses incorrectly).
-        ipv6_1xformat = u'1:2:3:4:5:6:7:8:9:a:b:c:d:e:f:1'
+        ipv6_1xformat = '1:2:3:4:5:6:7:8:9:a:b:c:d:e:f:1'
         addr_attr.typeName = "PhysAddress"
 
         addr = addr_attr.type(addr_attr, ipv6_1xformat)
@@ -408,7 +406,7 @@ class TestMibSnimpy(unittest.TestCase):
 
         # Parse error.
         attr.typeName = "InetAddressIPv4"
-        self.assertRaises(ValueError, attr.type, attr, u"01:02:03:04")
+        self.assertRaises(ValueError, attr.type, attr, "01:02:03:04")
 
     def testTypeName(self):
         """Check that we can get the current declared type name"""
@@ -432,8 +430,8 @@ class TestSmi(unittest.TestCase):
     def testGetPath(self):
         """Test we can get default SMI path"""
         current = mib.path()
-        self.assertTrue(type(current), unicode)
-        self.assertNotEqual(mib.path(), u"")
+        self.assertTrue(type(current), str)
+        self.assertNotEqual(mib.path(), "")
 
     def testSetPath(self):
         """Test we can set path to some value"""
